Interface MessageTransformer

  • All Known Implementing Classes:
    MessageTransformer.Typed

    @Beta
    public interface MessageTransformer
    Intercept every message before it is built in order to add additional data.
    • Nested Class Summary

      Nested Classes 
      Modifier and Type Interface Description
      static class  MessageTransformer.Typed
      A MessageTransformer that lets you implement more strongly typed methods and add transformations specific to the event type.
    • Method Detail

      • transform

        boolean transform​(com.segment.analytics.messages.MessageBuilder builder)
        Called for every builder. This will be called on the same thread the request was made and before any MessageInterceptor's are called. Returning false will skip processing this message any further.