Package com.segment.analytics
-
Interface Summary Interface Description Callback Callback invoked when the client library is done processing a message.Log Abstraction for logging messages.MessageInterceptor Intercept every message after it is built to process it further.MessageTransformer Intercept every message before it is built in order to add additional data.Plugin Plugins configure anAnalytics.Builderinstance. -
Class Summary Class Description Analytics The entry point into the Segment for Java library.Analytics.Builder Fluent API for creatingAnalyticsinstances.MessageInterceptor.Typed AMessageInterceptorthat lets you implement more strongly typed methods and add transformations specific to the event type.MessageTransformer.Typed AMessageTransformerthat lets you implement more strongly typed methods and add transformations specific to the event type. -
Enum Summary Enum Description Log.Level