All Classes and Interfaces
Class
Description
The entry point into the Segment for Java library.
Fluent API for creating
Analytics instances.Callback invoked when the client library is done processing a message.
Abstraction for logging messages.
Intercept every message after it is built to process it further.
A
MessageInterceptor that lets you implement more strongly typed methods and add
transformations specific to the event type.Intercept every message before it is built in order to add additional data.
A
MessageTransformer that lets you implement more strongly typed methods and add
transformations specific to the event type.Plugins configure an
Analytics.Builder instance.