All Classes
| Class | Description |
|---|---|
| Analytics |
The entry point into the Segment for Java library.
|
| Analytics.Builder |
Fluent API for creating
Analytics instances. |
| AnalyticsClient | |
| AnalyticsVersion | |
| Callback |
Callback invoked when the client library is done processing a message.
|
| Log |
Abstraction for logging messages.
|
| Log.Level | |
| MessageInterceptor |
Intercept every message after it is built to process it further.
|
| MessageInterceptor.Typed |
A
MessageInterceptor that lets you implement more strongly typed methods and add
transformations specific to the event type. |
| MessageTransformer |
Intercept every message before it is built in order to add additional data.
|
| MessageTransformer.Typed |
A
MessageTransformer that lets you implement more strongly typed methods and add
transformations specific to the event type. |
| Plugin |
Plugins configure an
Analytics.Builder instance. |